==> dde-launchpad_0.4.6.tar.xz: BUILD/translations/dde-launchpad_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="30"/>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="40"/>
        <source>Pin to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="49"/>
        <source>Remove from favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="49"/>
        <source>Add to favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="63"/>
        <source>Send to desktop</source>
        <translation>Send til skrivebord</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="63"/>
        <source>Remove from desktop</source>
        <translation>Fjern fra skrivebordet</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="73"/>
        <source>Send to dock</source>
        <translation>Send til dock</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="73"/>
        <source>Remove from dock</source>
        <translation>Fjern fra dokk</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="84"/>
        <source>Add to startup</source>
        <translation>Legg til oppstart</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="84"/>
        <source>Remove from startup</source>
        <translation>Fjern fra oppstart</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="89"/>
        <source>Use a proxy</source>
        <translation>Bruk en Proxy</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="95"/>
        <source>Disable display scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="102"/>
        <source>Uninstall</source>
        <translation>Avinstaller</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">Internett</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">Musikk</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">Grafikk</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">Kontor</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Lesing</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">Utvikling</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">System</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Søk</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="19"/>
        <source>Internet</source>
        <translation type="unfinished">Internett</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="21"/>
        <source>Chat</source>
        <translation type="unfinished">Chat</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="23"/>
        <source>Music</source>
        <translation type="unfinished">Musikk</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="25"/>
        <source>Video</source>
        <translation type="unfinished">Video</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="27"/>
        <source>Graphics</source>
        <translation type="unfinished">Grafikk</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="29"/>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="31"/>
        <source>Office</source>
        <translation type="unfinished">Kontor</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="33"/>
        <source>Reading</source>
        <translation type="unfinished">Lesing</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="35"/>
        <source>Development</source>
        <translation type="unfinished">Utvikling</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="37"/>
        <source>System</source>
        <translation type="unfinished">System</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="39"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="270"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="282"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="296"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="103"/>
        <source>Power</source>
        <translation>Strøm</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Instillinger</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="361"/>
        <location filename="../qml/WindowedFrame.qml" line="266"/>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="115"/>
        <source>Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="157"/>
        <source>My Favorites</source>
        <translation>Mine favoritter</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="191"/>
        <source>Add your favorite apps here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="202"/>
        <source>All Apps</source>
        <translation>Alle programmer</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="346"/>
        <location filename="../qml/WindowedFrame.qml" line="230"/>
        <source>No search results</source>
        <translation>Ingen søkeresultater</translation>
    </message>
</context>
</TS>

==> dde-launchpad_0.6.12.tar.xz: BUILD/translations/dde-launchpad_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>AnalysisView</name>
    <message>
        <source>No search results</source>
        <translation type="obsolete">Ingen søkeresultater</translation>
    </message>
</context>
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="31"/>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="41"/>
        <source>Pin to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="50"/>
        <source>Remove from favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="50"/>
        <source>Add to favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="64"/>
        <source>Send to desktop</source>
        <translation>Send til skrivebord</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="64"/>
        <source>Remove from desktop</source>
        <translation>Fjern fra skrivebordet</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="74"/>
        <source>Send to dock</source>
        <translation>Send til dock</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="74"/>
        <source>Remove from dock</source>
        <translation>Fjern fra dokk</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="85"/>
        <source>Add to startup</source>
        <translation>Legg til oppstart</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="85"/>
        <source>Remove from startup</source>
        <translation>Fjern fra oppstart</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="92"/>
        <source>Use a proxy</source>
        <translation>Bruk en Proxy</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="100"/>
        <source>Disable display scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="107"/>
        <source>Uninstall</source>
        <translation>Avinstaller</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">Internett</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">Musikk</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">Grafikk</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">Kontor</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Lesing</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">Utvikling</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">System</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="26"/>
        <source>Power</source>
        <translation type="unfinished">Strøm</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="40"/>
        <source>Search</source>
        <translation type="unfinished">Søk</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="29"/>
        <source>Frequently Used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="29"/>
        <source>All Apps</source>
        <translation type="unfinished">Alle programmer</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Søk</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="21"/>
        <source>Internet</source>
        <translation type="unfinished">Internett</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="23"/>
        <source>Chat</source>
        <translation type="unfinished">Chat</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="25"/>
        <source>Music</source>
        <translation type="unfinished">Musikk</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="27"/>
        <source>Video</source>
        <translation type="unfinished">Video</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="29"/>
        <source>Graphics</source>
        <translation type="unfinished">Grafikk</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="31"/>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="33"/>
        <source>Office</source>
        <translation type="unfinished">Kontor</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="35"/>
        <source>Reading</source>
        <translation type="unfinished">Lesing</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="37"/>
        <source>Development</source>
        <translation type="unfinished">Utvikling</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="39"/>
        <source>System</source>
        <translation type="unfinished">System</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="41"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="313"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="325"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="339"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="27"/>
        <source>Recently Installed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="26"/>
        <source>All Apps</source>
        <translation type="unfinished">Alle programmer</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="76"/>
        <source>No search results</source>
        <translation type="unfinished">Ingen søkeresultater</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="39"/>
        <source>Free sorting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="52"/>
        <source>Sort by category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="64"/>
        <source>Sort by name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="124"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="139"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="154"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="169"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="184"/>
        <source>Control Center</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Power</source>
        <translation type="vanished">Strøm</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Instillinger</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Søk</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="vanished">Mine favoritter</translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="vanished">Alle programmer</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation type="vanished">Ingen søkeresultater</translation>
    </message>
</context>
</TS>
